..  Titling
    ##++::==~~--''``

Balladeer
+++++++++

API Documentation
:::::::::::::::::

.. toctree::
   :maxdepth: 1

   intro
   types
   entity
   world
   map
   speech
   drama
   story
   scene
   themes
   style
   web
   screenshots
   changes

.. include:: ../../README.rst

.. _GNU General Public License: http://www.gnu.org/licenses/gpl.html
.. _issue tracker: https://github.com/tundish/balladeer/issues
.. _online documentation: https://balladeer.readthedocs.io/en/latest/index.html

